Releases
========

master
------

18.2.0
------

 * September 26, 2018
 * `carml` is now Python3-only
 * add :ref:`onion` sub-command to add Onion services to a Tor instance


18.1.0
------

 * June 26, 2018


18.0.0
------

 * April 16, 2018


17.4.0
------

 * May 15, 2017


17.3.0 and earlier
------------------

 * see `PyPI <https://pypi.org/project/carml/#history PyPI>`_


0.0.0 - 0.0.6
-------------

 * August 3, 2014
 * Initial release. Some issues with PyPI caused my to have to incrememnt the version several times.
